==> dde-shell_2.0.3.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Style d&apos;indicateur</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode productif</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mode classique</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mode centré</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Toujours affiché</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Toujours caché</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Masquage intelligemment</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Réglages du dock</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Verrouiller le Dock</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.2.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Style d&apos;indicateur</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode productif</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mode classique</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mode centré</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Toujours affiché</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Toujours caché</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Masquage intelligent</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Réglages du dock</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Verrouiller le Dock</translation>
    </message>
</context>
</TS>
